import { AccessLevelList } from '../../shared/access-level';
import { PolicyStatement } from '../../shared';
import { aws_iam as iam } from "aws-cdk-lib";
/**
 * Statement provider for service [invoicing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsinvoicingservice.html).
 *
 * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
 */
export declare class Invoicing extends PolicyStatement {
    servicePrefix: string;
    /**
     * Grants permission to get Invoice Email Delivery Preferences
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions
     */
    toGetInvoiceEmailDeliveryPreferences(): this;
    /**
     * Grants permission to get Invoice PDF
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions
     */
    toGetInvoicePDF(): this;
    /**
     * Grants permission to get Invoice summary information for your account or linked account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions
     */
    toListInvoiceSummaries(): this;
    /**
     * Grants permission to put Invoice Email Delivery Preferences
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions
     */
    toPutInvoiceEmailDeliveryPreferences(): this;
    protected accessLevelList: AccessLevelList;
    /**
     * Statement provider for service [invoicing](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsinvoicingservice.html).
     *
     */
    constructor(props?: iam.PolicyStatementProps);
}
